@@ -12,7 +12,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -623,45 +623,16 @@ function makeFiltersResponsive() {
 	if ($('div.cactiTableButton').closest('.cactiTable').find('.filterTable').length > 0) {
 		$('div.cactiTableButton').each(function() {
 			if ($(this).closest('.cactiTable').find('.filterTable').length) {
-				id    = $(this).closest('.cactiTable').attr('id');
-				child = id+'_child';
-
-				markFilterTDs(child, filterNum);
-
-				$(this).parent().css('cursor', 'pointer');
-
-				if ($(this).find('a').length) {
-					$(this).find('a').attr('title', $(this).find('a').text()).addClass('fa fa-plus').tooltip({
-						open: function (event, ui) {
-							id = $(this).closest('.cactiTable').attr('id');
-							$('#'+id).find('.cactiTableButton').tooltip('close');
-						},
-						close: function (event, ui) {
-							id = $(this).closest('.cactiTable').attr('id');
-						}
-					}).text('');
-				}
-
-				if ($('#'+child).find('.filterTable').length) {
-					$(this).append('<span style="display:none;" class="cactiFilter fa fa-filter"></span>');
-
-					$(this).attr('title', showHideFilter).tooltip({ track: true });
-
-					$('.cactiFilter').click(function(event) {
-						//$('.filterTable').find('td').css('display', 'table-row');
-						//event.stopPropagation();
-					});
-
+				if ($(this).find('.cactiFilterState').length == 0) {
 					id    = $(this).closest('.cactiTable').attr('id');
 					child = id+'_child';
 
-					if ($('#'+child).find('#clear').length) {
-						$(this).append('<span title="'+clearFilterTitle+'" style="display:none;" class="cactiFilterClear fa fa-trash-o"></span>');
+					markFilterTDs(child, filterNum);
 
-						$('.cactiFilterClear').click(function(event) {
-							event.stopPropagation();
-							$('#clear').trigger('click');
-						}).tooltip({
+					$(this).parent().css('cursor', 'pointer');
+
+					if ($(this).find('a').length) {
+						$(this).find('a').attr('title', $(this).find('a').text()).addClass('fa fa-plus').tooltip({
 							open: function (event, ui) {
 								id = $(this).closest('.cactiTable').attr('id');
 								$('#'+id).find('.cactiTableButton').tooltip('close');
@@ -669,24 +640,57 @@ function makeFiltersResponsive() {
 							close: function (event, ui) {
 								id = $(this).closest('.cactiTable').attr('id');
 							}
-						});
+						}).text('');
 					}
-
-					toggleFilterAndIcon(id, child, true);
-
-					$(this).parent().click(function() {
-						id    = $(this).closest('.cactiTable').attr('id');
-						child = id+'_child';
-						toggleFilterAndIcon(id, child, false);
-					});
 				}
 
-				state = storage.get('filterVisibility');
+				if ($('#'+child).find('.filterTable').length) {
+					if ($(this).find('.cactiFilter').length == 0) {
+						$(this).append('<span style="display:none;" class="cactiFilter fa fa-filter"></span>');
 
-				if (state == 'hidden') {
-					$(this).append('<span class="cactiFilterState fa fa-angle-double-down"></span>');
-				} else {
-					$(this).append('<span class="cactiFilterState fa fa-angle-double-up"></span>');
+						$(this).attr('title', showHideFilter).tooltip({ track: true });
+
+						$('.cactiFilter').click(function(event) {
+							//$('.filterTable').find('td').css('display', 'table-row');
+							//event.stopPropagation();
+						});
+
+						id    = $(this).closest('.cactiTable').attr('id');
+						child = id+'_child';
+
+						if ($('#'+child).find('#clear').length) {
+							$(this).append('<span title="'+clearFilterTitle+'" style="display:none;" class="cactiFilterClear fa fa-trash-o"></span>');
+
+							$('.cactiFilterClear').click(function(event) {
+								event.stopPropagation();
+								$('#clear').trigger('click');
+							}).tooltip({
+								open: function (event, ui) {
+									id = $(this).closest('.cactiTable').attr('id');
+									$('#'+id).find('.cactiTableButton').tooltip('close');
+								},
+								close: function (event, ui) {
+									id = $(this).closest('.cactiTable').attr('id');
+								}
+							});
+						}
+
+						toggleFilterAndIcon(id, child, true);
+
+						$(this).parent().click(function() {
+							id    = $(this).closest('.cactiTable').attr('id');
+							child = id+'_child';
+							toggleFilterAndIcon(id, child, false);
+						});
+
+						state = storage.get('filterVisibility');
+
+						if (state == 'hidden') {
+							$(this).append('<span class="cactiFilterState fa fa-angle-double-down"></span>');
+						} else {
+							$(this).append('<span class="cactiFilterState fa fa-angle-double-up"></span>');
+						}
+					}
 				}
 			} else {
 				if ($(this).find('a').length) {
