@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -649,7 +649,7 @@ function dsstats_poller_output(&$rrd_update_array) {
 							$last_delim = ', ';
 						}
 
-						if ($currentval == '') {
+						if ($currentval == '' || $currentval == '-') {
 							$currentval = 'NULL';
 						}
 
@@ -722,7 +722,7 @@ function dsstats_poller_output(&$rrd_update_array) {
    @returns - NULL */
 function dsstats_boost_bottom() {
 	global $config;
-	
+
 	if (read_config_option('dsstats_enable') == 'on') {
 		include_once($config['base_path'] . '/lib/rrd.php');
 
@@ -768,7 +768,7 @@ function dsstats_poller_bottom () {
 		} else {
 			$extra_args = '-q ' . $config['base_path'] . '/poller_dsstats.php';
 		}
-	
+
 		exec_background($command_string, $extra_args);
 	}
 }
