@@ -13,7 +13,7 @@
    | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
    | GNU General Public License for more details.                            |
    +-------------------------------------------------------------------------+
-   | Cacti: The Complete RRDTool-based Graphing Solution                     |
+   | Cacti: The Complete RRDtool-based Graphing Solution                     |
    +-------------------------------------------------------------------------+
    | This code is designed, written, and maintained by the Cacti Group. See  |
    | about.php and/or the AUTHORS file for specific developer information.   |
@@ -647,7 +647,7 @@ function manager_notifications($id, $header_label) {
     form_end();
 }
 
-function manager_logs($id) {
+function manager_logs($id, $header_label) {
 	$severity_levels = array(
 		SNMPAGENT_EVENT_SEVERITY_LOW      => 'LOW',
 		SNMPAGENT_EVENT_SEVERITY_MEDIUM   => 'MEDIUM',
